Enlightenment CVS committal

Author  : atmosphere
Project : e17
Module  : proto

Dir     : e17/proto/esmart/src/thumb


Modified Files:
        E_Thumb.c Esmart_Thumb.h md5.c md5.h 


Log Message:
namespace cleanup and indenting
===================================================================
RCS file: /cvsroot/enlightenment/e17/proto/esmart/src/thumb/E_Thumb.c,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -3 -r1.16 -r1.17
--- E_Thumb.c   21 Apr 2004 22:46:06 -0000      1.16
+++ E_Thumb.c   21 Apr 2004 22:53:25 -0000      1.17
@@ -27,18 +27,18 @@
 static void _e_thumb_color_set (Evas_Object * o, int r, int g, int b, int a);
 
 Evas_Object *
-e_thumb_new (Evas * evas, const char *file)
+esmart_thumb_new (Evas * evas, const char *file)
 {
   char buf[PATH_MAX];
   Evas_Object *result = NULL;
   if (file)
     {
-      E_Thumb *e = NULL;
+      Esmart_Thumb *e = NULL;
       static Evas_Smart *s = NULL;
 
       if (!s)
        {
-         s = evas_smart_new ("E_Thumb",
+         s = evas_smart_new ("Esmart_Thumb",
                              _e_thumb_add,
                              _e_thumb_del,
                              _e_thumb_layer_set,
@@ -55,7 +55,7 @@
        }
       result = evas_object_smart_add (evas, s);
 
-      if ((e = (E_Thumb *) evas_object_smart_data_get (result)))
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (result)))
        {
          if (!realpath (file, buf))
            snprintf (buf, PATH_MAX, "%s", file);
@@ -64,7 +64,7 @@
            {
              if (epsilon_exists (e->e) == EPSILON_FAIL)
                {
-                 e_thumb_free (result);
+                 esmart_thumb_free (result);
                  result = NULL;
                }
              else
@@ -79,7 +79,7 @@
                    }
                  else
                    {
-                     e_thumb_free (result);
+                     esmart_thumb_free (result);
                      e->image = NULL;
                    }
 
@@ -92,18 +92,18 @@
 }
 
 void
-e_thumb_free (Evas_Object * o)
+esmart_thumb_free (Evas_Object * o)
 {
   if (o)
     evas_object_del (o);
 }
 const char *
-e_thumb_file_get (Evas_Object * o)
+esmart_thumb_file_get (Evas_Object * o)
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        if (e->e)
          return (e->e->src);
     }
@@ -111,12 +111,12 @@
 }
 
 void
-e_thumb_geometry_get (Evas_Object * o, int *w, int *h)
+esmart_thumb_geometry_get (Evas_Object * o, int *w, int *h)
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          if (!e->info)
            e->info = epsilon_info_get (e->e);
@@ -128,13 +128,13 @@
     }
 }
 Evas_Object *
-e_thumb_evas_object_get (Evas_Object * o)
+esmart_thumb_evas_object_get (Evas_Object * o)
 {
   Evas_Object *result = NULL;
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          Imlib_Image tmp = NULL;
 
@@ -162,13 +162,13 @@
 }
 
 const char *
-e_thumb_format_get (Evas_Object * o)
+esmart_thumb_format_get (Evas_Object * o)
 {
   char *result = NULL;
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          if (!e->info)
            e->info = epsilon_info_get (e->e);
@@ -179,13 +179,13 @@
 }
 
 int
-e_thumb_freshen (Evas_Object * o)
+esmart_thumb_freshen (Evas_Object * o)
 {
   int result = EPSILON_FAIL;
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          if (epsilon_exists (e->e) == EPSILON_FAIL)
            {
@@ -227,10 +227,10 @@
 static void
 _e_thumb_add (Evas_Object * o)
 {
-  E_Thumb *e = NULL;
+  Esmart_Thumb *e = NULL;
 
-  e = (E_Thumb *) malloc (sizeof (E_Thumb));
-  memset (e, 0, sizeof (E_Thumb));
+  e = (Esmart_Thumb *) malloc (sizeof (Esmart_Thumb));
+  memset (e, 0, sizeof (Esmart_Thumb));
 
   evas_object_smart_data_set (o, e);
 }
@@ -244,8 +244,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)) == NULL)
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)) == NULL)
        {
          if (e->image)
            evas_object_del (e->image);
@@ -267,8 +267,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          if (e->image)
            evas_object_layer_set (e->image, layer);
@@ -285,8 +285,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_raise (e->image);
        }
@@ -302,8 +302,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_lower (e->image);
        }
@@ -321,8 +321,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_stack_above (e->image, above);
        }
@@ -340,8 +340,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_stack_below (e->image, below);
        }
@@ -359,8 +359,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          e->x = x;
          e->y = y;
@@ -380,8 +380,8 @@
 {
   if (o && (w > 1) && (h > 1))
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          double ww = w, hh = h;
          e->w = w;
@@ -408,8 +408,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_show (e->image);
        }
@@ -425,8 +425,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_hide (e->image);
        }
@@ -446,8 +446,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_color_set (e->image, r, g, b, a);
        }
@@ -464,8 +464,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_clip_set (e->image, clip);
        }
@@ -481,8 +481,8 @@
 {
   if (o)
     {
-      E_Thumb *e = NULL;
-      if ((e = (E_Thumb *) evas_object_smart_data_get (o)))
+      Esmart_Thumb *e = NULL;
+      if ((e = (Esmart_Thumb *) evas_object_smart_data_get (o)))
        {
          evas_object_clip_unset (e->image);
        }
===================================================================
RCS file: /cvsroot/enlightenment/e17/proto/esmart/src/thumb/Esmart_Thumb.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
--- md5.c       14 Sep 2003 00:30:39 -0000      1.1
+++ md5.c       21 Apr 2004 22:53:42 -0000      1.2
@@ -21,20 +21,23 @@
 #if (__BYTE_ORDER == 1234)
 #define byteReverse(buf, len)  /* Nothing */
 #else
-void byteReverse(unsigned char *buf, unsigned longs);
+void byteReverse (unsigned char *buf, unsigned longs);
 
 /*
  * Note: this code is harmless on little-endian machines.
  */
-void byteReverse(unsigned char *buf, unsigned longs)
+void
+byteReverse (unsigned char *buf, unsigned longs)
 {
-    u_int32_t t;
-    do {
-       t = (u_int32_t) ((unsigned) buf[3] << 8 | buf[2]) << 16 |
-           ((unsigned) buf[1] << 8 | buf[0]);
-       *(u_int32_t *) buf = t;
-       buf += 4;
-    } while (--longs);
+  u_int32_t t;
+  do
+    {
+      t = (u_int32_t) ((unsigned) buf[3] << 8 | buf[2]) << 16 |
+       ((unsigned) buf[1] << 8 | buf[0]);
+      *(u_int32_t *) buf = t;
+      buf += 4;
+    }
+  while (--longs);
 }
 #endif
 
@@ -42,108 +45,117 @@
  * Start MD5 accumulation.  Set bit count to 0 and buffer to mysterious
  * initialization constants.
  */
-void MD5Init(MD5_CTX *ctx)
+void
+MD5Init (MD5_CTX * ctx)
 {
-    ctx->buf[0] = 0x67452301;
-    ctx->buf[1] = 0xefcdab89;
-    ctx->buf[2] = 0x98badcfe;
-    ctx->buf[3] = 0x10325476;
+  ctx->buf[0] = 0x67452301;
+  ctx->buf[1] = 0xefcdab89;
+  ctx->buf[2] = 0x98badcfe;
+  ctx->buf[3] = 0x10325476;
 
-    ctx->bits[0] = 0;
-    ctx->bits[1] = 0;
+  ctx->bits[0] = 0;
+  ctx->bits[1] = 0;
 }
 
 /*
  * Update context to reflect the concatenation of another buffer full
  * of bytes.
  */
-void MD5Update(MD5_CTX *ctx, unsigned char const *buf, unsigned len)
+void
+MD5Update (MD5_CTX * ctx, unsigned char const *buf, unsigned len)
 {
-    u_int32_t t;
+  u_int32_t t;
 
-    /* Update bitcount */
+  /* Update bitcount */
 
-    t = ctx->bits[0];
-    if ((ctx->bits[0] = t + ((u_int32_t) len << 3)) < t)
-       ctx->bits[1]++;         /* Carry from low to high */
-    ctx->bits[1] += len >> 29;
+  t = ctx->bits[0];
+  if ((ctx->bits[0] = t + ((u_int32_t) len << 3)) < t)
+    ctx->bits[1]++;            /* Carry from low to high */
+  ctx->bits[1] += len >> 29;
 
-    t = (t >> 3) & 0x3f;       /* Bytes already in shsInfo->data */
+  t = (t >> 3) & 0x3f;         /* Bytes already in shsInfo->data */
 
-    /* Handle any leading odd-sized chunks */
+  /* Handle any leading odd-sized chunks */
 
-    if (t) {
-       unsigned char *p = (unsigned char *) ctx->in + t;
+  if (t)
+    {
+      unsigned char *p = (unsigned char *) ctx->in + t;
 
-       t = 64 - t;
-       if (len < t) {
-           memcpy(p, buf, len);
-           return;
+      t = 64 - t;
+      if (len < t)
+       {
+         memcpy (p, buf, len);
+         return;
        }
-       memcpy(p, buf, t);
-       byteReverse(ctx->in, 16);
-       MD5Transform(ctx->buf, (u_int32_t *) ctx->in);
-       buf += t;
-       len -= t;
+      memcpy (p, buf, t);
+      byteReverse (ctx->in, 16);
+      MD5Transform (ctx->buf, (u_int32_t *) ctx->in);
+      buf += t;
+      len -= t;
     }
-    /* Process data in 64-byte chunks */
+  /* Process data in 64-byte chunks */
 
-    while (len >= 64) {
-       memcpy(ctx->in, buf, 64);
-       byteReverse(ctx->in, 16);
-       MD5Transform(ctx->buf, (u_int32_t *) ctx->in);
-       buf += 64;
-       len -= 64;
+  while (len >= 64)
+    {
+      memcpy (ctx->in, buf, 64);
+      byteReverse (ctx->in, 16);
+      MD5Transform (ctx->buf, (u_int32_t *) ctx->in);
+      buf += 64;
+      len -= 64;
     }
 
-    /* Handle any remaining bytes of data. */
+  /* Handle any remaining bytes of data. */
 
-    memcpy(ctx->in, buf, len);
+  memcpy (ctx->in, buf, len);
 }
 
 /*
  * Final wrapup - pad to 64-byte boundary with the bit pattern 
  * 1 0* (64-bit count of bits processed, MSB-first)
  */
-void MD5Final(unsigned char digest[16], MD5_CTX *ctx)
+void
+MD5Final (unsigned char digest[16], MD5_CTX * ctx)
 {
-    unsigned count;
-    unsigned char *p;
+  unsigned count;
+  unsigned char *p;
+
+  /* Compute number of bytes mod 64 */
+  count = (ctx->bits[0] >> 3) & 0x3F;
 
-    /* Compute number of bytes mod 64 */
-    count = (ctx->bits[0] >> 3) & 0x3F;
+  /* Set the first char of padding to 0x80.  This is safe since there is
+     always at least one byte free */
+  p = ctx->in + count;
+  *p++ = 0x80;
+
+  /* Bytes of padding needed to make 64 bytes */
+  count = 64 - 1 - count;
+
+  /* Pad out to 56 mod 64 */
+  if (count < 8)
+    {
+      /* Two lots of padding:  Pad the first block to 64 bytes */
+      memset (p, 0, count);
+      byteReverse (ctx->in, 16);
+      MD5Transform (ctx->buf, (u_int32_t *) ctx->in);
 
-    /* Set the first char of padding to 0x80.  This is safe since there is
-       always at least one byte free */
-    p = ctx->in + count;
-    *p++ = 0x80;
-
-    /* Bytes of padding needed to make 64 bytes */
-    count = 64 - 1 - count;
-
-    /* Pad out to 56 mod 64 */
-    if (count < 8) {
-       /* Two lots of padding:  Pad the first block to 64 bytes */
-       memset(p, 0, count);
-       byteReverse(ctx->in, 16);
-       MD5Transform(ctx->buf, (u_int32_t *) ctx->in);
-
-       /* Now fill the next block with 56 bytes */
-       memset(ctx->in, 0, 56);
-    } else {
-       /* Pad block to 56 bytes */
-       memset(p, 0, count - 8);
+      /* Now fill the next block with 56 bytes */
+      memset (ctx->in, 0, 56);
+    }
+  else
+    {
+      /* Pad block to 56 bytes */
+      memset (p, 0, count - 8);
     }
-    byteReverse(ctx->in, 14);
+  byteReverse (ctx->in, 14);
 
-    /* Append length in bits and transform */
-    ((u_int32_t *) ctx->in)[14] = ctx->bits[0];
-    ((u_int32_t *) ctx->in)[15] = ctx->bits[1];
-
-    MD5Transform(ctx->buf, (u_int32_t *) ctx->in);
-    byteReverse((unsigned char *) ctx->buf, 4);
-    memcpy(digest, ctx->buf, 16);
-    memset((char *) ctx, 0, sizeof(ctx));      /* In case it's sensitive */
+  /* Append length in bits and transform */
+  ((u_int32_t *) ctx->in)[14] = ctx->bits[0];
+  ((u_int32_t *) ctx->in)[15] = ctx->bits[1];
+
+  MD5Transform (ctx->buf, (u_int32_t *) ctx->in);
+  byteReverse ((unsigned char *) ctx->buf, 4);
+  memcpy (digest, ctx->buf, 16);
+  memset ((char *) ctx, 0, sizeof (ctx));      /* In case it's sensitive */
 }
 
 /* The four core functions - F1 is optimized somewhat */
@@ -163,85 +175,86 @@
  * reflect the addition of 16 longwords of new data.  MD5Update blocks
  * the data and converts bytes into longwords for this routine.
  */
-void MD5Transform(u_int32_t buf[4], u_int32_t const in[16])
+void
+MD5Transform (u_int32_t buf[4], u_int32_t const in[16])
 {
-    register u_int32_t a, b, c, d;
+  register u_int32_t a, b, c, d;
 
-    a = buf[0];
-    b = buf[1];
-    c = buf[2];
-    d = buf[3];
-
-    MD5STEP(F1, a, b, c, d, in[0] + 0xd76aa478, 7);
-    MD5STEP(F1, d, a, b, c, in[1] + 0xe8c7b756, 12);
-    MD5STEP(F1, c, d, a, b, in[2] + 0x242070db, 17);
-    MD5STEP(F1, b, c, d, a, in[3] + 0xc1bdceee, 22);
-    MD5STEP(F1, a, b, c, d, in[4] + 0xf57c0faf, 7);
-    MD5STEP(F1, d, a, b, c, in[5] + 0x4787c62a, 12);
-    MD5STEP(F1, c, d, a, b, in[6] + 0xa8304613, 17);
-    MD5STEP(F1, b, c, d, a, in[7] + 0xfd469501, 22);
-    MD5STEP(F1, a, b, c, d, in[8] + 0x698098d8, 7);
-    MD5STEP(F1, d, a, b, c, in[9] + 0x8b44f7af, 12);
-    MD5STEP(F1, c, d, a, b, in[10] + 0xffff5bb1, 17);
-    MD5STEP(F1, b, c, d, a, in[11] + 0x895cd7be, 22);
-    MD5STEP(F1, a, b, c, d, in[12] + 0x6b901122, 7);
-    MD5STEP(F1, d, a, b, c, in[13] + 0xfd987193, 12);
-    MD5STEP(F1, c, d, a, b, in[14] + 0xa679438e, 17);
-    MD5STEP(F1, b, c, d, a, in[15] + 0x49b40821, 22);
-
-    MD5STEP(F2, a, b, c, d, in[1] + 0xf61e2562, 5);
-    MD5STEP(F2, d, a, b, c, in[6] + 0xc040b340, 9);
-    MD5STEP(F2, c, d, a, b, in[11] + 0x265e5a51, 14);
-    MD5STEP(F2, b, c, d, a, in[0] + 0xe9b6c7aa, 20);
-    MD5STEP(F2, a, b, c, d, in[5] + 0xd62f105d, 5);
-    MD5STEP(F2, d, a, b, c, in[10] + 0x02441453, 9);
-    MD5STEP(F2, c, d, a, b, in[15] + 0xd8a1e681, 14);
-    MD5STEP(F2, b, c, d, a, in[4] + 0xe7d3fbc8, 20);
-    MD5STEP(F2, a, b, c, d, in[9] + 0x21e1cde6, 5);
-    MD5STEP(F2, d, a, b, c, in[14] + 0xc33707d6, 9);
-    MD5STEP(F2, c, d, a, b, in[3] + 0xf4d50d87, 14);
-    MD5STEP(F2, b, c, d, a, in[8] + 0x455a14ed, 20);
-    MD5STEP(F2, a, b, c, d, in[13] + 0xa9e3e905, 5);
-    MD5STEP(F2, d, a, b, c, in[2] + 0xfcefa3f8, 9);
-    MD5STEP(F2, c, d, a, b, in[7] + 0x676f02d9, 14);
-    MD5STEP(F2, b, c, d, a, in[12] + 0x8d2a4c8a, 20);
-
-    MD5STEP(F3, a, b, c, d, in[5] + 0xfffa3942, 4);
-    MD5STEP(F3, d, a, b, c, in[8] + 0x8771f681, 11);
-    MD5STEP(F3, c, d, a, b, in[11] + 0x6d9d6122, 16);
-    MD5STEP(F3, b, c, d, a, in[14] + 0xfde5380c, 23);
-    MD5STEP(F3, a, b, c, d, in[1] + 0xa4beea44, 4);
-    MD5STEP(F3, d, a, b, c, in[4] + 0x4bdecfa9, 11);
-    MD5STEP(F3, c, d, a, b, in[7] + 0xf6bb4b60, 16);
-    MD5STEP(F3, b, c, d, a, in[10] + 0xbebfbc70, 23);
-    MD5STEP(F3, a, b, c, d, in[13] + 0x289b7ec6, 4);
-    MD5STEP(F3, d, a, b, c, in[0] + 0xeaa127fa, 11);
-    MD5STEP(F3, c, d, a, b, in[3] + 0xd4ef3085, 16);
-    MD5STEP(F3, b, c, d, a, in[6] + 0x04881d05, 23);
-    MD5STEP(F3, a, b, c, d, in[9] + 0xd9d4d039, 4);
-    MD5STEP(F3, d, a, b, c, in[12] + 0xe6db99e5, 11);
-    MD5STEP(F3, c, d, a, b, in[15] + 0x1fa27cf8, 16);
-    MD5STEP(F3, b, c, d, a, in[2] + 0xc4ac5665, 23);
-
-    MD5STEP(F4, a, b, c, d, in[0] + 0xf4292244, 6);
-    MD5STEP(F4, d, a, b, c, in[7] + 0x432aff97, 10);
-    MD5STEP(F4, c, d, a, b, in[14] + 0xab9423a7, 15);
-    MD5STEP(F4, b, c, d, a, in[5] + 0xfc93a039, 21);
-    MD5STEP(F4, a, b, c, d, in[12] + 0x655b59c3, 6);
-    MD5STEP(F4, d, a, b, c, in[3] + 0x8f0ccc92, 10);
-    MD5STEP(F4, c, d, a, b, in[10] + 0xffeff47d, 15);
-    MD5STEP(F4, b, c, d, a, in[1] + 0x85845dd1, 21);
-    MD5STEP(F4, a, b, c, d, in[8] + 0x6fa87e4f, 6);
-    MD5STEP(F4, d, a, b, c, in[15] + 0xfe2ce6e0, 10);
-    MD5STEP(F4, c, d, a, b, in[6] + 0xa3014314, 15);
-    MD5STEP(F4, b, c, d, a, in[13] + 0x4e0811a1, 21);
-    MD5STEP(F4, a, b, c, d, in[4] + 0xf7537e82, 6);
-    MD5STEP(F4, d, a, b, c, in[11] + 0xbd3af235, 10);
-    MD5STEP(F4, c, d, a, b, in[2] + 0x2ad7d2bb, 15);
-    MD5STEP(F4, b, c, d, a, in[9] + 0xeb86d391, 21);
-
-    buf[0] += a;
-    buf[1] += b;
-    buf[2] += c;
-    buf[3] += d;
+  a = buf[0];
+  b = buf[1];
+  c = buf[2];
+  d = buf[3];
+
+  MD5STEP (F1, a, b, c, d, in[0] + 0xd76aa478, 7);
+  MD5STEP (F1, d, a, b, c, in[1] + 0xe8c7b756, 12);
+  MD5STEP (F1, c, d, a, b, in[2] + 0x242070db, 17);
+  MD5STEP (F1, b, c, d, a, in[3] + 0xc1bdceee, 22);
+  MD5STEP (F1, a, b, c, d, in[4] + 0xf57c0faf, 7);
+  MD5STEP (F1, d, a, b, c, in[5] + 0x4787c62a, 12);
+  MD5STEP (F1, c, d, a, b, in[6] + 0xa8304613, 17);
+  MD5STEP (F1, b, c, d, a, in[7] + 0xfd469501, 22);
+  MD5STEP (F1, a, b, c, d, in[8] + 0x698098d8, 7);
+  MD5STEP (F1, d, a, b, c, in[9] + 0x8b44f7af, 12);
+  MD5STEP (F1, c, d, a, b, in[10] + 0xffff5bb1, 17);
+  MD5STEP (F1, b, c, d, a, in[11] + 0x895cd7be, 22);
+  MD5STEP (F1, a, b, c, d, in[12] + 0x6b901122, 7);
+  MD5STEP (F1, d, a, b, c, in[13] + 0xfd987193, 12);
+  MD5STEP (F1, c, d, a, b, in[14] + 0xa679438e, 17);
+  MD5STEP (F1, b, c, d, a, in[15] + 0x49b40821, 22);
+
+  MD5STEP (F2, a, b, c, d, in[1] + 0xf61e2562, 5);
+  MD5STEP (F2, d, a, b, c, in[6] + 0xc040b340, 9);
+  MD5STEP (F2, c, d, a, b, in[11] + 0x265e5a51, 14);
+  MD5STEP (F2, b, c, d, a, in[0] + 0xe9b6c7aa, 20);
+  MD5STEP (F2, a, b, c, d, in[5] + 0xd62f105d, 5);
+  MD5STEP (F2, d, a, b, c, in[10] + 0x02441453, 9);
+  MD5STEP (F2, c, d, a, b, in[15] + 0xd8a1e681, 14);
+  MD5STEP (F2, b, c, d, a, in[4] + 0xe7d3fbc8, 20);
+  MD5STEP (F2, a, b, c, d, in[9] + 0x21e1cde6, 5);
+  MD5STEP (F2, d, a, b, c, in[14] + 0xc33707d6, 9);
+  MD5STEP (F2, c, d, a, b, in[3] + 0xf4d50d87, 14);
+  MD5STEP (F2, b, c, d, a, in[8] + 0x455a14ed, 20);
+  MD5STEP (F2, a, b, c, d, in[13] + 0xa9e3e905, 5);
+  MD5STEP (F2, d, a, b, c, in[2] + 0xfcefa3f8, 9);
+  MD5STEP (F2, c, d, a, b, in[7] + 0x676f02d9, 14);
+  MD5STEP (F2, b, c, d, a, in[12] + 0x8d2a4c8a, 20);
+
+  MD5STEP (F3, a, b, c, d, in[5] + 0xfffa3942, 4);
+  MD5STEP (F3, d, a, b, c, in[8] + 0x8771f681, 11);
+  MD5STEP (F3, c, d, a, b, in[11] + 0x6d9d6122, 16);
+  MD5STEP (F3, b, c, d, a, in[14] + 0xfde5380c, 23);
+  MD5STEP (F3, a, b, c, d, in[1] + 0xa4beea44, 4);
+  MD5STEP (F3, d, a, b, c, in[4] + 0x4bdecfa9, 11);
+  MD5STEP (F3, c, d, a, b, in[7] + 0xf6bb4b60, 16);
+  MD5STEP (F3, b, c, d, a, in[10] + 0xbebfbc70, 23);
+  MD5STEP (F3, a, b, c, d, in[13] + 0x289b7ec6, 4);
+  MD5STEP (F3, d, a, b, c, in[0] + 0xeaa127fa, 11);
+  MD5STEP (F3, c, d, a, b, in[3] + 0xd4ef3085, 16);
+  MD5STEP (F3, b, c, d, a, in[6] + 0x04881d05, 23);
+  MD5STEP (F3, a, b, c, d, in[9] + 0xd9d4d039, 4);
+  MD5STEP (F3, d, a, b, c, in[12] + 0xe6db99e5, 11);
+  MD5STEP (F3, c, d, a, b, in[15] + 0x1fa27cf8, 16);
+  MD5STEP (F3, b, c, d, a, in[2] + 0xc4ac5665, 23);
+
+  MD5STEP (F4, a, b, c, d, in[0] + 0xf4292244, 6);
+  MD5STEP (F4, d, a, b, c, in[7] + 0x432aff97, 10);
+  MD5STEP (F4, c, d, a, b, in[14] + 0xab9423a7, 15);
+  MD5STEP (F4, b, c, d, a, in[5] + 0xfc93a039, 21);
+  MD5STEP (F4, a, b, c, d, in[12] + 0x655b59c3, 6);
+  MD5STEP (F4, d, a, b, c, in[3] + 0x8f0ccc92, 10);
+  MD5STEP (F4, c, d, a, b, in[10] + 0xffeff47d, 15);
+  MD5STEP (F4, b, c, d, a, in[1] + 0x85845dd1, 21);
+  MD5STEP (F4, a, b, c, d, in[8] + 0x6fa87e4f, 6);
+  MD5STEP (F4, d, a, b, c, in[15] + 0xfe2ce6e0, 10);
+  MD5STEP (F4, c, d, a, b, in[6] + 0xa3014314, 15);
+  MD5STEP (F4, b, c, d, a, in[13] + 0x4e0811a1, 21);
+  MD5STEP (F4, a, b, c, d, in[4] + 0xf7537e82, 6);
+  MD5STEP (F4, d, a, b, c, in[11] + 0xbd3af235, 10);
+  MD5STEP (F4, c, d, a, b, in[2] + 0x2ad7d2bb, 15);
+  MD5STEP (F4, b, c, d, a, in[9] + 0xeb86d391, 21);
+
+  buf[0] += a;
+  buf[1] += b;
+  buf[2] += c;
+  buf[3] += d;
 }
===================================================================
RCS file: /cvsroot/enlightenment/e17/proto/esmart/src/thumb/md5.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
--- md5.h       14 Sep 2003 00:30:39 -0000      1.1
+++ md5.h       21 Apr 2004 22:53:42 -0000      1.2
@@ -5,19 +5,21 @@
 
 #define MD5_HASHBYTES 16
 
-typedef struct MD5Context {
-       u_int32_t buf[4];
-       u_int32_t bits[2];
-       unsigned char in[64];
+typedef struct MD5Context
+{
+  u_int32_t buf[4];
+  u_int32_t bits[2];
+  unsigned char in[64];
 } MD5_CTX;
 
-extern void   MD5Init(MD5_CTX *context);
-extern void   MD5Update(MD5_CTX *context,unsigned char const *buf,unsigned len);
-extern void   MD5Final(unsigned char digest[MD5_HASHBYTES], MD5_CTX *context);
+extern void MD5Init (MD5_CTX * context);
+extern void MD5Update (MD5_CTX * context, unsigned char const *buf,
+                      unsigned len);
+extern void MD5Final (unsigned char digest[MD5_HASHBYTES], MD5_CTX * context);
 
-extern void   MD5Transform(u_int32_t buf[4], u_int32_t const in[16]);
-extern char  *MD5End(MD5_CTX *, char *);
-extern char  *MD5File(const char *, char *);
-extern char  *MD5Data (const unsigned char *, unsigned int, char *);
+extern void MD5Transform (u_int32_t buf[4], u_int32_t const in[16]);
+extern char *MD5End (MD5_CTX *, char *);
+extern char *MD5File (const char *, char *);
+extern char *MD5Data (const unsigned char *, unsigned int, char *);
 
 #endif




-------------------------------------------------------
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
_______________________________________________
enlightenment-cvs mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs

Reply via email to
diff -u -3 -r1.1 -r1.2
--- Esmart_Thumb.h      21 Apr 2004 22:46:11 -0000      1.1
+++ Esmart_Thumb.h      21 Apr 2004 22:53:41 -0000      1.2
@@ -14,7 +14,7 @@
  * Version 0.0.1 - August 23rd 2003 <[EMAIL PROTECTED]>
  *  - This was done hastily, there will be fixes
  */
-struct _E_Thumb
+struct _Esmart_Thumb
 {
   Epsilon *e;
   Epsilon_Info *info;
@@ -22,54 +22,54 @@
   double x, y, w, h;           /* smart object location/geometry */
   int tw, th;
 };
-typedef struct _E_Thumb E_Thumb;
+typedef struct _Esmart_Thumb Esmart_Thumb;
 
 /**
  * e_thumb_free - free an E_Thumb smart object 
  */
-void e_thumb_free (Evas_Object * o);
+void esmart_thumb_free (Evas_Object * o);
 /**
  * e_thumb_new - create a new E_Thumb object.  If the freedesktop cached
  * thumbnail exists it loads it, if not it creates it.  There's some
  * metadata in there if you're curious.
  * @evas - the evas we want to add the object to
  * @file - the name of the file we want a thumb of
  */
-Evas_Object *e_thumb_new (Evas * evas, const char *file);
+Evas_Object *esmart_thumb_new (Evas * evas, const char *file);
 /**
  * e_thumb_file_get - get the full path to the thumbnail's real image
  * @o - The smart object we want the filename for
  * Returns a pointer to the filename, you should NOT free this memory
  */
-const char *e_thumb_file_get (Evas_Object * o);
+const char *esmart_thumb_file_get (Evas_Object * o);
 /**
  * e_thumb_geometry_get - Get the geometry of the source image
  * @o - The smart object we want the geometry of
  * @w - A pointer to somewhere we can store the width
  * @h - A pointer to somewhere we can store the height
  */
-void e_thumb_geometry_get (Evas_Object * o, int *w, int *h);
+void esmart_thumb_geometry_get (Evas_Object * o, int *w, int *h);
 
 /**
  * e_thumb_evas_object_get - Load the image file to an evas object
  * @o - The smart object we want the geometry of
  * Returns a valid Evas_Object if imlib2 or evas can load the file
  */
-Evas_Object *e_thumb_evas_object_get (Evas_Object * o);
+Evas_Object *esmart_thumb_evas_object_get (Evas_Object * o);
 
 /**
  * e_thumb_format_get - get the format of the image this thumb is for
  * @o - The smart object we want the format for
  * NOTE: Don't free this string, dupe it if you wanna keep it around
  */
-const char *e_thumb_format_get (Evas_Object * o);
+const char *esmart_thumb_format_get (Evas_Object * o);
 
 /** 
  * e_thumb_freshen - forced reloading of the thumbnail image from disk
  * @o - The smart object we want the format for
  * Returns EPSILON_OK if the cache was bad and we regenerated, EPSILON_FAIL
  * if the cached image is still valid
  */
-int e_thumb_freshen (Evas_Object * o);
+int esmart_thumb_freshen (Evas_Object * o);
 
 #endif
@@ -22,54 +22,54 @@
 
 /**
- * e_thumb_free - free an E_Thumb smart object 
+ * esmart_thumb_free - free an E_Thumb smart object 
  */
@@ -22,54 +22,54 @@
 /**
- * e_thumb_new - create a new E_Thumb object.  If the freedesktop cached
+ * esmart_thumb_new - create a new E_Thumb object.  If the freedesktop cached
  * thumbnail exists it loads it, if not it creates it.  There's some
  * metadata in there if you're curious.
@@ -22,54 +22,54 @@
 /**
- * e_thumb_file_get - get the full path to the thumbnail's real image
+ * esmart_thumb_file_get - get the full path to the thumbnail's real image
  * @o - The smart object we want the filename for
  * Returns a pointer to the filename, you should NOT free this memory
@@ -22,54 +22,54 @@
 /**
- * e_thumb_geometry_get - Get the geometry of the source image
+ * esmart_thumb_geometry_get - Get the geometry of the source image
  * @o - The smart object we want the geometry of
  * @w - A pointer to somewhere we can store the width
@@ -22,54 +22,54 @@
 
 /**
- * e_thumb_evas_object_get - Load the image file to an evas object
+ * esmart_thumb_evas_object_get - Load the image file to an evas object
  * @o - The smart object we want the geometry of
  * Returns a valid Evas_Object if imlib2 or evas can load the file
@@ -22,54 +22,54 @@
 
 /**
- * e_thumb_format_get - get the format of the image this thumb is for
+ * esmart_thumb_format_get - get the format of the image this thumb is for
  * @o - The smart object we want the format for
  * NOTE: Don't free this string, dupe it if you wanna keep it around
@@ -22,54 +22,54 @@
 
 /** 
- * e_thumb_freshen - forced reloading of the thumbnail image from disk
+ * esmart_thumb_freshen - forced reloading of the thumbnail image from disk
  * @o - The smart object we want the format for
  * Returns EPSILON_OK if the cache was bad and we regenerated, EPSILON_FAIL
===================================================================
RCS file: /cvsroot/enlightenment/e17/proto/esmart/src/thumb/md5.c,v
retrieving revision 1.1
retrieving revision 1.2